@@ -39,7 +39,7 @@ class LinkAllMixin(models.Model):
     link_url = models.CharField(max_length=1024, blank=True)
     link_label = models.CharField(max_length=1024, blank=True)
     link_is_open_in_new_tab = models.BooleanField(default=False, verbose_name="Open in a new tab")
-    link_is_optional = True
+    link_is_optional = False
 
     class Meta:
         abstract = True
